@@ -97,20 +97,6 @@ class CommandLineInterface(CommandBase):
                 'search', etc.""").rstrip(),
             default='json', choices=['status', 'json']
         )
-        parser.add_argument(
-            '--username',
-            dest='username',
-            type=str,
-            help='Basic auth username',
-            default=None
-        )
-        parser.add_argument(
-            '--password',
-            dest='password',
-            type=str,
-            help='Basic auth password',
-            default=None
-        )
         parser.add_argument(
             '--creds',
             dest='creds',
@@ -138,6 +124,13 @@ class CommandLineInterface(CommandBase):
             help="Fail if no authentication credentials are found",
             default=False
         )
+        parser.add_argument(
+            "--use-auth",
+            dest='use_auth',
+            type=str,
+            help="Select with authentication method to use",
+            default='all', choices=['all', 'x509', 'scitoken']
+        )
         return parser
 
     # Utils -------------------------------------------------------------------
@@ -171,10 +164,9 @@ class CommandLineInterface(CommandBase):
         client_kwargs = {
             'service_url': args.service,
             'force_noauth': args.force_noauth,
-            'username': args.username,
-            'password': args.password,
             'fail_if_noauth': args.fail_if_noauth,
             'cred': creds,
+            'use_auth': args.use_auth,
         }
 
         # Initialize client
