@@ -69,9 +69,6 @@ def test_cli_client_setup(CLI):
     """Test translation of CLI arguments into client instantiation"""
     arg_dict = {
         'service-url': 'testserver.com',
-        'proxy': 'testproxy.com:123',
-        'username': 'user',
-        'password': 'passw0rd',
         'creds': 'cert_file,key_file',
     }
     args = ['--{k}={v}'.format(k=k, v=v) for k, v in six.iteritems(arg_dict)]
@@ -88,6 +85,4 @@ def test_cli_client_setup(CLI):
     cli_args, cli_kwargs = mock_client.call_args
     assert cli_args == ()
     assert cli_kwargs['service_url'] == arg_dict['service-url']
-    assert cli_kwargs['username'] == arg_dict['username']
-    assert cli_kwargs['password'] == arg_dict['password']
     assert cli_kwargs['cred'] == arg_dict['creds'].split(',')
