@@ -22,17 +22,22 @@ import six
 import sys
 from six.moves import map
 from six.moves.urllib.parse import urlencode
+from urllib.parse import urlparse
 
+from .alias import alias, aliased
 from .exceptions import HTTPError
 from .utils import event_or_superevent, dict_to_form_encoded, get_mimetype
 from .client import GraceDBClient
 
 DEFAULT_SERVICE_URL = "https://gracedb.ligo.org/api/"
 
+TOKEN_SCOPE = "read:/GraceDB"
+
 
 # -----------------------------------------------------------------
 # GraceDb REST client
 # -----------------------------------------------------------------
+@aliased
 class GraceDb(GraceDBClient):
     """GraceDb REST client class.
 
@@ -44,8 +49,6 @@ class GraceDb(GraceDBClient):
 
     #. If provided, import X.509 credentials from the certificate-key \
         pair or combined proxy file provided in the ``cred`` keyword arg.
-    #. If provided, use the username and password provided in the \
-        keyword arguments.
     #. If the ``X509_USER_CERT`` and ``X509_USER_KEY`` environment variables \
         are set, load the corresponding certificate and key.
     #. If the ``X509_USER_PROXY`` environment variable is set, load the \
@@ -54,7 +57,6 @@ class GraceDb(GraceDBClient):
         (``/tmp/x509up_u${UID}``).
     #. Look for a certificate and key file in ``$HOME/.globus/usercert.pem`` \
         and ``$HOME/.globus/userkey.pem``.
-    #. Look for a username and password for the server in ``$HOME/.netrc``.
     #. Continue with no authentication credentials.
 
     Args:
@@ -62,18 +64,6 @@ class GraceDb(GraceDBClient):
         cred (:obj:`tuple` or :obj:`str`, optional): a tuple or list of
             (``/path/to/cert/file``, ``/path/to/key/file``) or a single path to
             a combined proxy file. Used for X.509 authentication only.
-        username (:obj:`str`, optional): username for basic auth.
-        password (:obj:`str`, optional): password for basic auth.
-        force_noauth (:obj:`bool`, optional): set to True if you want to
-            skip credential lookup and use this client without
-            authenticating to the server.
-        fail_if_noauth (:obj:`bool`, optional): set to ``True`` if you want the
-            client constructor to fail if no authentication credentials are
-            provided or found.
-        api_version (:obj:`str`, optional): choose the version of the server
-            API to use.  At present, there is only one version, but this
-            argument is provided with the expectation that this will change
-            in the future.
         reload_certificate (:obj:`bool`, optional): if True, your certificate
             will be checked before each request whether it is within
             ``reload_buffer`` seconds of expiration, and if so, it will be
@@ -99,15 +89,29 @@ class GraceDb(GraceDBClient):
         >>> g = GraceDb(cred=('/path/to/cert/file', '/path/to/key/file'))
     """
     def __init__(self, service_url=DEFAULT_SERVICE_URL,
-                 cred=None, username=None, password=None,
+                 cred=None,
                  force_noauth=False, fail_if_noauth=False, api_version=None,
-                 reload_certificate=False, reload_buffer=300):
+                 reload_certificate=False, reload_buffer=300, use_auth='all'):
+
+        # Set allowed SciToken audience to specified server.
+        u = urlparse(service_url)
+        TOKEN_AUDIENCE = [
+            "ANY",
+            f"{u.scheme}://{u.netloc}",
+            f"{u.scheme}://{u.hostname}",
+        ]
+
         """Create a client instance."""
-        super(GraceDb, self).__init__(
+        super().__init__(
             service_url,
-            cred=cred, username=username, password=password,
-            force_noauth=force_noauth, fail_if_noauth=fail_if_noauth,
-            reload_certificate=reload_certificate, reload_buffer=reload_buffer
+            cred=cred,
+            token_audience=TOKEN_AUDIENCE,
+            token_scope=TOKEN_SCOPE,
+            force_noauth=force_noauth,
+            fail_if_noauth=fail_if_noauth,
+            reload_certificate=reload_certificate,
+            reload_buffer=reload_buffer,
+            use_auth=use_auth,
         )
 
         # Check version type
@@ -258,12 +262,6 @@ class GraceDb(GraceDBClient):
         """List of available signoff statuses on the server."""
         return self.service_info.get('signoff-statuses')
 
-#   def request(self, method, url, body=None, headers=None, priming_url=None):
-#       if (method.upper() in ['POST', 'PUT'] and self.auth_type == 'x509'):
-#           priming_url = self._service_url
-#       return super(GraceDb, self).request(
-#           method, url, body, headers, priming_url)
-
     def _getCode(self, input_value, code_dict):
         """
         Check if input is valid and return coded version if it is
@@ -285,8 +283,9 @@ class GraceDb(GraceDBClient):
         return None
 
     # Search and filecontents are optional when creating an event.
-    def createEvent(self, group, pipeline, filename, search=None, labels=None,
-                    offline=False, filecontents=None, **kwargs):
+    @alias('createEvent')
+    def create_event(self, group, pipeline, filename, search=None, labels=None,
+                     offline=False, filecontents=None, **kwargs):
         """Create a new event on the server.
 
         All LIGO-Virgo users can create events in the 'Test' group. Special
@@ -346,10 +345,10 @@ class GraceDb(GraceDBClient):
                 raise TypeError("labels arg is {0}, should be str or list"
                                 .format(type(labels)))
             # Check labels against those in database
-            for l in labels:
-                if l not in self.allowed_labels:
+            for label in labels:
+                if label not in self.allowed_labels:
                     raise ValueError(("Label '{0}' does not exist in the "
-                                     "database").format(l))
+                                     "database").format(label))
         if filecontents is None:
             if filename == '-':
                 filename = 'initial.data'
@@ -389,7 +388,8 @@ class GraceDb(GraceDBClient):
 
         return self.post(uri, data=fields, files=files)
 
-    def replaceEvent(self, graceid, filename, filecontents=None):
+    @alias('replaceEvent')
+    def replace_event(self, graceid, filename, filecontents=None):
         """Replace an existing event by uploading a new event file.
 
         The event's parameters are updated from the new file. Only the user
@@ -412,7 +412,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.replaceEvent('T101383', '/path/to/new/something.xml')
+            >>> r = g.replace_event('T101383', '/path/to/new/something.xml')
         """
         if filecontents is None:
             # Note: not allowing filename '-' here.  We want the event datafile
@@ -555,10 +555,11 @@ class GraceDb(GraceDBClient):
             for event in events:
                 n += 1
                 if (max_results is not None and n > max_results):
-                    break
+                    return
                 yield event
 
-    def numEvents(self, query=None):
+    @alias('numEvents')
+    def num_events(self, query=None):
         """Get the number of events satisfying a query.
 
         Args:
@@ -573,7 +574,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> g.numEvents('ER5 submitter: "gstlalcbc"')
+            >>> g.num_events('ER5 submitter: "gstlalcbc"')
             213
         """
         uri = self.links['events']
@@ -581,8 +582,9 @@ class GraceDb(GraceDBClient):
             uri += "?" + urlencode({'query': query})
         return self.get(uri).json()['numRows']
 
-    def createSuperevent(self, t_start, t_0, t_end, preferred_event,
-                         category='production', events=None, labels=None):
+    @alias('createSuperevent')
+    def create_superevent(self, t_start, t_0, t_end, preferred_event,
+                          category='production', events=None, labels=None):
         r"""Create a superevent.
 
         All LIGO-Virgo users can create test superevents, but special
@@ -615,7 +617,7 @@ class GraceDb(GraceDBClient):
         Example:
 
             >>> g = GraceDb()
-            >>> r = g.createSuperevent(1, 2, 3, 'G123456',
+            >>> r = g.create_superevent(1, 2, 3, 'G123456',
             ... category='production', events=['G100', 'G101'],
             ... labels=['EM_READY', 'DQV'])
             >>> r.status_code
@@ -628,17 +630,18 @@ class GraceDb(GraceDBClient):
                 labels = [labels]
             elif isinstance(labels, (list, tuple)):
                 # Validate each entry
-                if any([not isinstance(l, six.string_types) for l in labels]):
+                if any(not isinstance(label, six.string_types)
+                       for label in labels):
                     err_msg = "One of the provided labels is not a string"
                     raise TypeError(err_msg)
             else:
                 raise TypeError("labels arg is {0}, should be str or list"
                                 .format(type(labels)))
             # Check labels against those in database
-            for l in labels:
-                if l not in self.allowed_labels:
+            for label in labels:
+                if label not in self.allowed_labels:
                     raise ValueError(("Label '{0}' does not exist in the "
-                                     "database").format(l))
+                                     "database").format(label))
         if events:
             if isinstance(events, six.string_types):
                 events = [events]
@@ -681,9 +684,10 @@ class GraceDb(GraceDBClient):
         uri = self.links['superevents']
         return self.post(uri, data=request_body)
 
-    def updateSuperevent(self, superevent_id, t_start=None, t_0=None,
-                         t_end=None, preferred_event=None, em_type=None,
-                         time_coinc_far=None, space_coinc_far=None):
+    @alias('updateSuperevent')
+    def update_superevent(self, superevent_id, t_start=None, t_0=None,
+                          t_end=None, preferred_event=None, em_type=None,
+                          time_coinc_far=None, space_coinc_far=None):
         r"""Update a superevent's parameters.
 
         The same permission restrictions apply as for
@@ -725,8 +729,8 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.updateSuperevent('S181224a', t_start=12, preferred_event=
-            ... 'G654321')
+            >>> r = g.update_superevent('S181224a', t_start=12,
+            ... preferred_event='G654321')
             >>> r.status_code
             200
         """  # noqa: W605
@@ -756,7 +760,8 @@ class GraceDb(GraceDBClient):
         uri = template.format(superevent_id=superevent_id)
         return self.patch(uri, data=request_body)
 
-    def addEventToSuperevent(self, superevent_id, graceid):
+    @alias('addEventToSuperevent')
+    def add_event_to_superevent(self, superevent_id, graceid):
         """Add an event to a superevent.
 
         The event must be in the same category as the superevent and must not
@@ -776,7 +781,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = addEventToSuperevent('S181224a', 'G123456')
+            >>> r = add_event_to_superevent('S181224a', 'G123456')
             >>> r.status_code
             201
         """
@@ -785,7 +790,8 @@ class GraceDb(GraceDBClient):
         uri = template.format(superevent_id=superevent_id)
         return self.post(uri, data=request_body)
 
-    def removeEventFromSuperevent(self, superevent_id, graceid):
+    @alias('removeEventFromSuperevent')
+    def remove_event_from_superevent(self, superevent_id, graceid):
         """Remove an event from a superevent.
 
         The event must already be a part of the superevent.
@@ -804,7 +810,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = removeEventFromSuperevent('S181224a', 'G123456')
+            >>> r = remove_event_from_superevent('S181224a', 'G123456')
             >>> r.status_code
             204
         """
@@ -812,6 +818,77 @@ class GraceDb(GraceDBClient):
         uri = template.format(superevent_id=superevent_id, graceid=graceid)
         return self.delete(uri)
 
+    def add_pipeline_preferred_event(self, superevent_id, graceid):
+        """Add an event to a superevent's pipeline-preferred
+           list. The event must already be part of a superevent,
+           and there can be only one event per pipeline in the list.
+
+           Adding a pipeline's event to the list, when an event from that
+           pipeline is already present will replace that event in the list,
+           except in the case where the existing event is the preferred event.
+
+        Args:
+            superevent_id (str): ID of the superevent to which the
+                pipeline-preferred event will be added.
+            graceid (str): graceid of the event to add to this superevent.
+
+        Returns:
+            :class:`requests.models.Response`
+
+        Raises:
+            ligo.gracedb.exceptions.HTTPError: if the response has a status
+                code >= 400.
+
+        Example:
+            >>> g = GraceDb()
+            >>> r = add_pipeline_preferred_event('S181224a', 'G123456')
+            >>> r.status_code
+            201
+        """
+        request_body = {'event': graceid}
+        try:
+            template = self.templates['superevent-pipeline'
+                                      '-preferred-event-list-template']
+        except KeyError:
+            raise UserWarning("Feature not enabled on the server")
+            return
+
+        uri = template.format(superevent_id=superevent_id)
+        return self.post(uri, data=request_body)
+
+    def remove_pipeline_preferred_event(self, superevent_id, graceid):
+        """Remove an event from a superevent's pipeline-preferred list
+
+        The event must already be a part of the preferred list. The preferred
+        event cannot be removed from the pipeline preferred list.
+
+        Args:
+            superevent_id (str): GraceDB ID of the superevent from which the
+                event will be removed.
+            graceid (str): graceid of the event to remove from this superevent.
+
+        Returns:
+            :class:`requests.models.Response`
+
+        Raises:
+            ligo.gracedb.exceptions.HTTPError: if the response has a status
+                code >= 400.
+
+        Example:
+            >>> g = GraceDb()
+            >>> r = remove_pipeline_preferred_event('S181224a', 'G123456')
+            >>> r.status_code
+            204
+        """
+        try:
+            template = self.templates['superevent-pipeline-preferred-'
+                                      'event-detail-template']
+        except KeyError:
+            raise UserWarning("Feature not enabled on the server")
+            return
+        uri = template.format(superevent_id=superevent_id, graceid=graceid)
+        return self.delete(uri)
+
     def superevent(self, superevent_id):
         """Get information about an individual superevent.
 
@@ -897,7 +974,7 @@ class GraceDb(GraceDBClient):
             for superevent in superevents:
                 n += 1
                 if (max_results is not None and n > max_results):
-                    break
+                    return
                 # If columns are specified, only return specific values
                 if columns:
                     yield {k: superevent[k] for k in columns}
@@ -1057,8 +1134,9 @@ class GraceDb(GraceDBClient):
         return self.get(uri)
 
     @event_or_superevent
-    def writeLog(self, object_id, message, filename=None, filecontents=None,
-                 tag_name=[], displayName=[], *args, **kwargs):
+    @alias('writeLog')
+    def write_log(self, object_id, message, filename=None, filecontents=None,
+                  tag_name=[], displayName=[], *args, **kwargs):
         """Create a new log entry associated with an event or superevent.
 
         Args:
@@ -1085,7 +1163,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.writeLog('T101383', 'Good stuff.', '/path/to/plot.png',
+            >>> r = g.write_log('T101383', 'Good stuff.', '/path/to/plot.png',
             ... tag_name='analyst_comments')
             >>> print r.status_code
             201
@@ -1211,9 +1289,10 @@ class GraceDb(GraceDBClient):
         return self.get(uri)
 
     @event_or_superevent
-    def writeEMObservation(self, object_id, group, raList, raWidthList,
-                           decList, decWidthList, startTimeList, durationList,
-                           comment="", *args, **kwargs):
+    @alias('writeEMObservation')
+    def write_emobservation(self, object_id, group, raList, raWidthList,
+                            decList, decWidthList, startTimeList, durationList,
+                            comment="", *args, **kwargs):
         """Create an EM observation data entry for an event or superevent.
 
         Args:
@@ -1245,7 +1324,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.writeEMObservation('S190131g', 'ZTF', [1, 2, 3],
+            >>> r = g.write_emobservation('S190131g', 'ZTF', [1, 2, 3],
             ... [0.1, 0.1, 0.1], [4, 5, 6], 0.2, [],
             ... [10, 9, 11], comment="data uploaded")
             >>> r.status
@@ -1261,8 +1340,10 @@ class GraceDb(GraceDBClient):
         num_measurements = len(raList)
         # convert any single number widths or durations into lists
         raWidthList, decWidthList, durationList = \
-            [[l] * num_measurements if not isinstance(l, (list, tuple)) else l
-                for l in [raWidthList, decWidthList, durationList]]
+            [[lst] * num_measurements
+             if not isinstance(lst, (list, tuple))
+             else lst
+             for lst in [raWidthList, decWidthList, durationList]]
 
         # Compare all list lengths
         all_lists = [raList, decList, startTimeList, raWidthList,
@@ -1344,7 +1425,8 @@ class GraceDb(GraceDBClient):
         return self.get(uri)
 
     @event_or_superevent
-    def writeLabel(self, object_id, label, *args, **kwargs):
+    @alias('writeLabel')
+    def write_label(self, object_id, label, *args, **kwargs):
         """Add a label to an event or superevent.
 
         Args:
@@ -1362,7 +1444,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.writeLabel('T101383', 'DQV')
+            >>> r = g.write_label('T101383', 'DQV')
             >>> r.status_code
             201
         """
@@ -1387,7 +1469,8 @@ class GraceDb(GraceDBClient):
             return self.put(uri, data=request_body)
 
     @event_or_superevent
-    def removeLabel(self, object_id, label, *args, **kwargs):
+    @alias('removeLabel')
+    def remove_label(self, object_id, label, *args, **kwargs):
         """Remove a label from an event or superevent.
 
         Args:
@@ -1404,7 +1487,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.removeLabel('T101383', 'DQV')
+            >>> r = g.remove_label('T101383', 'DQV')
             >>> r.status_code
             204
         """
@@ -1452,8 +1535,9 @@ class GraceDb(GraceDBClient):
         return self.get(uri)
 
     @event_or_superevent
-    def addTag(self, object_id, N, tag_name, displayName=None, *args,
-               **kwargs):
+    @alias('addTag')
+    def add_tag(self, object_id, N, tag_name, displayName=None, *args,
+                **kwargs):
         """Add a tag to an event or superevent log entry.
 
         Args:
@@ -1473,7 +1557,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.createTag('T101383', 56, 'sky_loc')
+            >>> r = g.add_tag('T101383', 56, 'sky_loc')
             >>> r.status
             201
         """
@@ -1499,7 +1583,8 @@ class GraceDb(GraceDBClient):
             return self.put(uri, data=request_body)
 
     @event_or_superevent
-    def removeTag(self, object_id, N, tag_name, *args, **kwargs):
+    @alias('removeTag')
+    def remove_tag(self, object_id, N, tag_name, *args, **kwargs):
         """Remove a tag from an event or superevent log entry.
 
         Args:
@@ -1517,7 +1602,7 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.deleteTag('T101383', 56, 'sky_loc')
+            >>> r = g.remove_tag('T101383', 56, 'sky_loc')
             >>> r.status
             200
         """
@@ -1600,12 +1685,13 @@ class GraceDb(GraceDBClient):
         return self.get(uri)
 
     @event_or_superevent
-    def createVOEvent(self, object_id, voevent_type, skymap_type=None,
-                      skymap_filename=None, combined_skymap_filename=None,
-                      internal=True, open_alert=False, raven_coinc=False,
-                      hardware_inj=False, CoincComment=False, ProbHasNS=None,
-                      ProbHasRemnant=None, BNS=None, NSBH=None, BBH=None,
-                      Terrestrial=None, MassGap=None, *args, **kwargs):
+    @alias('createVOEvent')
+    def create_voevent(self, object_id, voevent_type, skymap_type=None,
+                       skymap_filename=None, combined_skymap_filename=None,
+                       internal=True, open_alert=False, raven_coinc=False,
+                       hardware_inj=False, CoincComment=False, ProbHasNS=None,
+                       ProbHasRemnant=None, BNS=None, NSBH=None, BBH=None,
+                       Terrestrial=None, MassGap=None, *args, **kwargs):
         r"""Create a new VOEvent.
 
         Args:
@@ -1657,9 +1743,9 @@ class GraceDb(GraceDBClient):
 
         Example:
             >>> g = GraceDb()
-            >>> r = g.createVOEvent('T101383', 'initial', skymap_type='custom',
-            ... skymap_filename='skymap.fits.gz', internal=True, ProbHasNS=0.7,
-            ... MassGap=0.4, Terrestrial=0.05)
+            >>> r = g.create_voevent('T101383', 'initial',
+            ... skymap_type='custom', skymap_filename='skymap.fits.gz',
+            ... internal=True, ProbHasNS=0.7, MassGap=0.4, Terrestrial=0.05)
             >>> r.status
             201
         """  # noqa: W605
