@@ -11,7 +11,7 @@ def test_logs(client, create_obj, obj_type):
 
     # Create a log
     comment = 'test comment'
-    response = client.writeLog(obj_id, comment)
+    response = client.write_log(obj_id, comment)
     assert response.status_code == 201
     data = response.json()
     assert data['comment'] == comment
@@ -39,7 +39,7 @@ def test_log_creation_with_tags(client, create_obj, obj_type):
     # Create a log with tags
     comment = 'test log with tags'
     tags = ['test_tag1', 'test_tag2']
-    response = client.writeLog(obj_id, comment, tag_name=tags)
+    response = client.write_log(obj_id, comment, tag_name=tags)
     assert response.status_code == 201
     data = response.json()
     assert data['comment'] == comment
@@ -54,7 +54,7 @@ def test_log_tag_and_untag(client, create_obj, obj_type):
 
     # Create a log
     comment = 'test log, add/remove tags later'
-    response = client.writeLog(obj_id, comment)
+    response = client.write_log(obj_id, comment)
     assert response.status_code == 201
     data = response.json()
     assert data['comment'] == comment
@@ -62,7 +62,7 @@ def test_log_tag_and_untag(client, create_obj, obj_type):
 
     # Add a tag
     tag = 'test_tag'
-    response = client.addTag(obj_id, log_N, tag)
+    response = client.add_tag(obj_id, log_N, tag)
     assert response.status_code == 201
 
     # Get log and check tag status
@@ -73,7 +73,7 @@ def test_log_tag_and_untag(client, create_obj, obj_type):
     assert tag in data['tag_names']
 
     # Remove tag
-    response = client.removeTag(obj_id, log_N, tag)
+    response = client.remove_tag(obj_id, log_N, tag)
     assert response.status_code == 204
 
     # Get log and check tag status
