@@ -7,7 +7,8 @@ pytestmark = pytest.mark.integration
 
 def test_basic_creation_and_retrieval(client, create_event):
     event = create_event()
-    response = client.createSuperevent(1, 2, 3, event['graceid'], category='T')
+    response = client.create_superevent(1, 2, 3,
+                                        event['graceid'], category='T')
     assert response.status_code == 201
     data = response.json()
     assert data['preferred_event'] == event['graceid']
@@ -28,7 +29,8 @@ def test_basic_creation_and_retrieval(client, create_event):
 
 def test_creation_with_already_used_preferred_event(client, create_event):
     event = create_event()
-    response = client.createSuperevent(1, 2, 3, event['graceid'], category='T')
+    response = client.create_superevent(1, 2, 3,
+                                        event['graceid'], category='T')
     assert response.status_code == 201
     data = response.json()
     assert data['preferred_event'] == event['graceid']
@@ -40,14 +42,14 @@ def test_creation_with_already_used_preferred_event(client, create_event):
     # Try to create new superevent with an existing
     # preferred event:
     with pytest.raises(HTTPError):
-        response = client.createSuperevent(1, 2, 3, event, category='T')
+        response = client.create_superevent(1, 2, 3, event, category='T')
 
 
 def test_creation_with_events(client, create_event):
     event1 = create_event()
     event2 = create_event()
     event3 = create_event()
-    response = client.createSuperevent(
+    response = client.create_superevent(
         1, 2, 3, event1['graceid'], category='T',
         events=[event2['graceid'], event3['graceid']]
     )
@@ -66,8 +68,9 @@ def test_creation_with_events(client, create_event):
 def test_creation_with_labels(client, create_event):
     labels = ['INJ', 'DQV']
     event = create_event()
-    response = client.createSuperevent(1, 2, 3, event['graceid'], category='T',
-                                       labels=labels)
+    response = client.create_superevent(1, 2, 3,
+                                        event['graceid'], category='T',
+                                        labels=labels)
     assert response.status_code == 201
     data = response.json()
     assert data['preferred_event'] == event['graceid']
@@ -76,8 +79,8 @@ def test_creation_with_labels(client, create_event):
     assert data['t_end'] == 3
     assert data['category'] == 'Test'
     assert len(data['labels']) == len(labels)
-    for l in labels:
-        assert l in data['labels']
+    for label in labels:
+        assert label in data['labels']
 
 
 @pytest.mark.parametrize(
@@ -107,7 +110,7 @@ def test_update(client, create_event, create_superevent, params):
         params['preferred_event'] = event['graceid']
 
     # Update the superevent
-    response = client.updateSuperevent(superevent['superevent_id'], **params)
+    response = client.update_superevent(superevent['superevent_id'], **params)
 
     # Check results
     assert response.status_code == 200
@@ -127,8 +130,8 @@ def test_event_addition_and_removal(client, create_event, create_superevent):
     new_event = create_event()
 
     # Add new event to superevent
-    response = client.addEventToSuperevent(superevent['superevent_id'],
-                                           new_event['graceid'])
+    response = client.add_event_to_superevent(superevent['superevent_id'],
+                                              new_event['graceid'])
 
     # Check results
     assert response.status_code == 201
@@ -147,8 +150,8 @@ def test_event_addition_and_removal(client, create_event, create_superevent):
     assert new_event['graceid'] in data['gw_events']
 
     # Remove event
-    response = client.removeEventFromSuperevent(superevent['superevent_id'],
-                                                new_event['graceid'])
+    response = client.remove_event_from_superevent(superevent['superevent_id'],
+                                                   new_event['graceid'])
     assert response.status_code == 204
 
     # Pull down superevent and check results
@@ -164,17 +167,84 @@ def test_event_addition_and_removal(client, create_event, create_superevent):
 
     # Try remove event again, should get error
     with pytest.raises(HTTPError):
-        client.removeEventFromSuperevent(
+        client.remove_event_from_superevent(
             superevent['superevent_id'], new_event['graceid']
         )
 
     # Try remove preferred event, should get error
     with pytest.raises(HTTPError):
-        client.removeEventFromSuperevent(
+        client.remove_event_from_superevent(
             superevent['superevent_id'], superevent['preferred_event']
         )
 
 
+def test_pipeline_preferred_add_remove(client, create_event,
+                                       create_event_spiir, create_superevent):
+    superevent = create_superevent()
+    spiir_event = create_event_spiir()
+
+    sid = superevent['superevent_id']
+    spiir_id = spiir_event['graceid']
+
+    # Confirm that the preferred event is in the pipeline_preferred
+    # response:
+
+    assert superevent['preferred_event'] == \
+        superevent['pipeline_preferred_events']['gstlal']['graceid']
+
+    # The superevent has the gstlal event as preferred. Try and add
+    # the spiir event without being part of the superevent. It should
+    # HTTPError 400
+
+    with pytest.raises(HTTPError):
+        client.add_pipeline_preferred_event(sid, spiir_id)
+
+    # Now add the spiir event to the superevent and verify that it 201's:
+    response = client.add_event_to_superevent(sid, spiir_id)
+    assert response.status_code == 201
+
+    # Now add the spiir event to the superevent's pipeline_preferred_events
+    # list.
+    response = client.add_pipeline_preferred_event(sid, spiir_id)
+    # Check results
+    assert response.status_code == 201
+    data = response.json()
+    assert data['graceid'] == spiir_id
+
+    response = client.superevent(sid)
+    data = response.json()
+    assert response.status_code == 200
+    assert data['pipeline_preferred_events']['spiir']['graceid'] == spiir_id
+
+    # Now the spiir event should remove without error:
+    response = client.remove_pipeline_preferred_event(sid, spiir_id)
+    # Check results:
+    assert response.status_code == 204
+    response = client.superevent(sid)
+    data = response.json()
+    assert response.status_code == 200
+    assert len(data['pipeline_preferred_events']) == 1
+
+    # Trying to remove again should result in a 404 error:
+    with pytest.raises(HTTPError):
+        client.remove_pipeline_preferred_event(sid, spiir_id)
+
+    # Add the spiir event back to the pipeline_preferred_events list:
+    response = client.add_pipeline_preferred_event(sid, spiir_id)
+    assert response.status_code == 201
+
+    # Now remove the spiir event from the superevent's event list:
+    response = client.remove_event_from_superevent(sid, spiir_id)
+    assert response.status_code == 204
+
+    # Check that the spiir event is no longer in the pipeline_preferred_evnts
+    # list:
+    response = client.superevent(sid)
+    data = response.json()
+    assert response.status_code == 200
+    assert len(data['pipeline_preferred_events']) == 1
+
+
 def test_confirm_as_gw(client, create_superevent):
     # Create superevent
     superevent = create_superevent()
