@@ -15,14 +15,16 @@ def test_x509_cert_load():
     cert_file = '/tmp/cert_file'
     key_file = '/tmp/key_file'
 
+    exists_func = 'os.path.exists'
     load_cert_func = 'ligo.gracedb.cert.load_certificate'
-    with mock.patch(load_cert_func) as mock_load_cert:
+    with mock.patch(load_cert_func), \
+         mock.patch(exists_func) as mock_load_cert:
         # Initialize client
         g = GraceDb(cred=(cert_file, key_file))
 
     # Check credentials
     assert len(g.cert) == 2
-    assert g.auth_type == 'x509'
+    assert 'x509' in g.auth_type
     assert g.cert[0] == cert_file
     assert g.cert[1] == key_file
     assert mock_load_cert.called_once()
@@ -54,10 +56,11 @@ def test_x509_cert_expiration(reload_buffer, x509_cert):
 
 
 # All possible combinations of True/False for the three variables
-RELOAD_TEST_DATA = list(itertools.product((True, False), repeat=3))
 @pytest.mark.skip(reason="tested online, figure out mocking in pytest'")
-@pytest.mark.parametrize("force_noauth,reload_cert,cert_expired",  # noqa: E302
-                         RELOAD_TEST_DATA)
+@pytest.mark.parametrize(
+    "force_noauth,reload_cert,cert_expired",
+    list(itertools.product((True, False), repeat=3)),
+)
 def test_reloading_feature(force_noauth, reload_cert, cert_expired):
     # Set up cert and key files
     cert_file = '/tmp/cert_file'
