@@ -47,8 +47,8 @@ def test_create_event(safe_client, group, pipeline, search, offline, labels):
          mock.patch(open_func, open_mocker), \
          mock.patch(si_property, mock_si_dict), \
          mock.patch(post_func) as mock_post:  # noqa: E127
-        safe_client.createEvent(group, pipeline, filename, search=search,
-                                labels=labels, offline=offline)
+        safe_client.create_event(group, pipeline, filename, search=search,
+                                 labels=labels, offline=offline)
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
@@ -101,7 +101,7 @@ def test_create_event_from_stdin(safe_client):
          mock.patch(stdin_obj) as mock_stdin, \
          mock.patch(post_func) as mock_post:  # noqa: E127
         mock_stdin.read.return_value = mock_stdin_data
-        safe_client.createEvent('g1', 'p1', '-')
+        safe_client.create_event('g1', 'p1', '-')
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
@@ -133,8 +133,8 @@ def test_create_event_with_filecontents(safe_client):
     with mock.patch(links_prop, new_callable=mock.PropertyMock), \
          mock.patch(si_property, mock_si_dict), \
          mock.patch(post_func) as mock_post:  # noqa: E127
-        safe_client.createEvent('g1', 'p1', filename,
-                                filecontents=filecontents)
+        safe_client.create_event('g1', 'p1', filename,
+                                 filecontents=filecontents)
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
@@ -153,7 +153,7 @@ def test_create_event_with_bad_group(safe_client):
     # Call
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(ValueError, match='bad group'):
-            safe_client.createEvent('g2', '', '')
+            safe_client.create_event('g2', '', '')
 
 
 def test_create_event_with_bad_pipeline(safe_client):
@@ -164,7 +164,7 @@ def test_create_event_with_bad_pipeline(safe_client):
     # Call
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(ValueError, match='bad pipeline'):
-            safe_client.createEvent('g1', 'p2', '')
+            safe_client.create_event('g1', 'p2', '')
 
 
 def test_create_event_with_bad_search(safe_client):
@@ -175,7 +175,7 @@ def test_create_event_with_bad_search(safe_client):
     # Call
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(ValueError, match='bad search'):
-            safe_client.createEvent('g1', 'p1', '', search='s2')
+            safe_client.create_event('g1', 'p1', '', search='s2')
 
 
 @pytest.mark.parametrize("offline", [1, 1.3, {}, [], (True,), None])
@@ -188,8 +188,8 @@ def test_create_event_with_bad_offline(safe_client, offline):
     err_msg = "offline parameter should be a bool"
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(TypeError, match=err_msg):
-            safe_client.createEvent('g1', 'p1', '', search='s1',
-                                    offline=offline)
+            safe_client.create_event('g1', 'p1', '', search='s1',
+                                     offline=offline)
 
 
 @pytest.mark.parametrize("labels", [1, 1.3, {}])
@@ -203,8 +203,8 @@ def test_create_event_with_bad_label_type(safe_client, labels):
         tl=type(labels))
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(TypeError, match=err_msg):
-            safe_client.createEvent('g1', 'p1', '', search='s1',
-                                    labels=labels)
+            safe_client.create_event('g1', 'p1', '', search='s1',
+                                     labels=labels)
 
 
 def test_create_event_with_bad_label_value(safe_client):
@@ -224,8 +224,8 @@ def test_create_event_with_bad_label_value(safe_client):
         label=label)
     with mock.patch(si_property, mock_si_dict):
         with pytest.raises(ValueError, match=err_msg):
-            safe_client.createEvent('g1', 'p1', '', search='s1',
-                                    labels=label)
+            safe_client.create_event('g1', 'p1', '', search='s1',
+                                     labels=label)
 
 
 @pytest.mark.parametrize(
@@ -238,16 +238,16 @@ def test_creation_with_bad_labels(safe_client, labels):
         mock_labels.return_value = ['GOOD_LABEL']
 
         with pytest.raises(ValueError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category='T', labels=labels)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category='T', labels=labels)
 
 
 @pytest.mark.parametrize("labels", [1, 2.34, {'test': 'bad'}, (1, 'GOOD')])
 def test_creation_with_bad_label_type(safe_client, labels):
 
     with pytest.raises(TypeError):
-        safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                     category='T', labels=labels)
+        safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                      category='T', labels=labels)
 
 
 @pytest.mark.parametrize("category", ['other', 'new', 'etc'])
@@ -261,8 +261,8 @@ def test_creation_with_bad_category(safe_client, category):
         }
 
         with pytest.raises(ValueError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category=category)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category=category)
 
 
 @pytest.mark.parametrize("category", [1, 2.34, {'test': 'bad'}, None])
@@ -276,8 +276,8 @@ def test_creation_with_bad_category_type(safe_client, category):
         }
 
         with pytest.raises(TypeError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category=category)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category=category)
     pass
 
 
@@ -287,8 +287,8 @@ def test_creation_with_bad_category_type(safe_client, category):
 )
 def test_creation_with_bad_event_graceids(safe_client, events):
     with pytest.raises(TypeError):
-        safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                     category='T', events=events)
+        safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                      category='T', events=events)
 
 
 @pytest.mark.parametrize(
@@ -316,7 +316,7 @@ def test_creation_args(
             'M': 'MDC',
         }
         mock_labels.return_value = ['DQV', 'INJ']
-        safe_client.createSuperevent(
+        safe_client.create_superevent(
             t_start, t_0, t_end, preferred_event, category=category,
             labels=labels, events=events
         )
@@ -343,7 +343,7 @@ def test_update_no_args(safe_client):
     err_msg = ('Provide at least one of t_start, t_0, t_end, preferred_event, '
                'em_type, time_coinc_far, or space_coinc_far')
     with pytest.raises(ValueError, match=err_msg):
-        safe_client.updateSuperevent('S181224a')
+        safe_client.update_superevent('S181224a')
 
 
 @pytest.mark.parametrize(
@@ -363,7 +363,7 @@ def test_update_no_args(safe_client):
 def test_update_args(safe_client, update_kwargs):
     with mock.patch('ligo.gracedb.rest.GraceDb.patch') as mock_patch, \
          mock.patch('ligo.gracedb.rest.GraceDb.templates'):  # noqa: E127
-        safe_client.updateSuperevent('S181224a', **update_kwargs)
+        safe_client.update_superevent('S181224a', **update_kwargs)
 
     # Check results
     call_args, call_kwargs = mock_patch.call_args
@@ -381,7 +381,7 @@ def test_add_event(safe_client):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.post') as mock_post, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.addEventToSuperevent(superevent_id, event_graceid)
+        safe_client.add_event_to_superevent(superevent_id, event_graceid)
 
     call_args, call_kwargs = mock_post.call_args
     assert call_kwargs['data'] == {'event': event_graceid}
@@ -400,7 +400,7 @@ def test_remove_event(safe_client):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.delete') as mock_delete, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.removeEventFromSuperevent(superevent_id, event_graceid)
+        safe_client.remove_event_from_superevent(superevent_id, event_graceid)
 
     delete_call_args, delete_call_kwargs = mock_delete.call_args
     assert len(delete_call_args) == 1
@@ -472,7 +472,7 @@ def test_replace_event(safe_client, filecontents):
     with mock.patch('ligo.gracedb.rest.GraceDb.put') as mock_put, \
          mock.patch(open_func, open_mocker), \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.replaceEvent(graceid, filename, filecontents=filecontents)
+        safe_client.replace_event(graceid, filename, filecontents=filecontents)
 
     # Check template call
     template_call_args, template_call_kwargs = mock_template.format.call_args
@@ -525,7 +525,7 @@ def test_num_events(safe_client, query):
     get_func = 'ligo.gracedb.rest.GraceDb.get'
     with mock.patch(link_prop, new_callable=mock.PropertyMock), \
          mock.patch(get_func) as mock_get:  # noqa: E127
-        safe_client.numEvents(query=query)
+        safe_client.num_events(query=query)
 
     # Check get calls
     assert len(mock_get.call_args[0]) == 1
