@@ -107,8 +107,8 @@ def test_write_log(safe_client, is_event, obj_id, tag_name, display_name):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.post') as mock_post, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.writeLog(obj_id, comment, tag_name=tag_name,
-                             displayName=display_name)
+        safe_client.write_log(obj_id, comment, tag_name=tag_name,
+                              displayName=display_name)
 
     # Test call to self.post
     post_call_args, post_call_kwargs = mock_post.call_args
@@ -170,7 +170,7 @@ def test_write_log_legacy_tagname(safe_client, tag_name, legacy_tagname):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.post') as mock_post, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.writeLog('TS121212abc', comment, **method_kwargs)
+        safe_client.write_log('TS121212abc', comment, **method_kwargs)
 
     # Test call to self.post
     post_call_args, post_call_kwargs = mock_post.call_args
@@ -201,5 +201,5 @@ def test_write_log_bad_tags(safe_client, tag_name, display_name):
     err_msg = ("For a list of tags, either provide no display names or a "
                "display name for each tag")
     with pytest.raises(ValueError, match=err_msg):
-        safe_client.writeLog('TS121212abc', 'test', tag_name=tag_name,
-                             displayName=display_name)
+        safe_client.write_log('TS121212abc', 'test', tag_name=tag_name,
+                              displayName=display_name)
