@@ -17,16 +17,16 @@ def test_creation_with_bad_labels(safe_client, labels):
         mock_labels.return_value = ['GOOD_LABEL']
 
         with pytest.raises(ValueError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category='T', labels=labels)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category='T', labels=labels)
 
 
 @pytest.mark.parametrize("labels", [1, 2.34, {'test': 'bad'}, (1, 'GOOD')])
 def test_creation_with_bad_label_type(safe_client, labels):
 
     with pytest.raises(TypeError):
-        safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                     category='T', labels=labels)
+        safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                      category='T', labels=labels)
 
 
 @pytest.mark.parametrize("category", ['other', 'new', 'etc'])
@@ -40,8 +40,8 @@ def test_creation_with_bad_category(safe_client, category):
         }
 
         with pytest.raises(ValueError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category=category)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category=category)
 
 
 @pytest.mark.parametrize("category", [1, 2.34, {'test': 'bad'}, None])
@@ -55,8 +55,8 @@ def test_creation_with_bad_category_type(safe_client, category):
         }
 
         with pytest.raises(TypeError):
-            safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                         category=category)
+            safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                          category=category)
     pass
 
 
@@ -66,8 +66,8 @@ def test_creation_with_bad_category_type(safe_client, category):
 )
 def test_creation_with_bad_event_graceids(safe_client, events):
     with pytest.raises(TypeError):
-        safe_client.createSuperevent(1, 2, 3, preferred_event='T0001',
-                                     category='T', events=events)
+        safe_client.create_superevent(1, 2, 3, preferred_event='T0001',
+                                      category='T', events=events)
 
 
 @pytest.mark.parametrize(
@@ -95,7 +95,7 @@ def test_creation_args(
             'M': 'MDC',
         }
         mock_labels.return_value = ['DQV', 'INJ']
-        safe_client.createSuperevent(
+        safe_client.create_superevent(
             t_start, t_0, t_end, preferred_event, category=category,
             labels=labels, events=events
         )
@@ -122,7 +122,7 @@ def test_update_no_args(safe_client):
     err_msg = ('Provide at least one of t_start, t_0, t_end, preferred_event, '
                'em_type, time_coinc_far, or space_coinc_far')
     with pytest.raises(ValueError, match=err_msg):
-        safe_client.updateSuperevent('S181224a')
+        safe_client.update_superevent('S181224a')
 
 
 @pytest.mark.parametrize(
@@ -142,7 +142,7 @@ def test_update_no_args(safe_client):
 def test_update_args(safe_client, update_kwargs):
     with mock.patch('ligo.gracedb.rest.GraceDb.patch') as mock_patch, \
          mock.patch('ligo.gracedb.rest.GraceDb.templates'):  # noqa: E127
-        safe_client.updateSuperevent('S181224a', **update_kwargs)
+        safe_client.update_superevent('S181224a', **update_kwargs)
 
     # Check results
     call_args, call_kwargs = mock_patch.call_args
@@ -160,7 +160,7 @@ def test_add_event(safe_client):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.post') as mock_post, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.addEventToSuperevent(superevent_id, event_graceid)
+        safe_client.add_event_to_superevent(superevent_id, event_graceid)
 
     call_args, call_kwargs = mock_post.call_args
     assert call_kwargs['data'] == {'event': event_graceid}
@@ -179,7 +179,50 @@ def test_remove_event(safe_client):
     template_prop = 'ligo.gracedb.rest.GraceDb.templates'
     with mock.patch('ligo.gracedb.rest.GraceDb.delete') as mock_delete, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
-        safe_client.removeEventFromSuperevent(superevent_id, event_graceid)
+        safe_client.remove_event_from_superevent(superevent_id, event_graceid)
+
+    delete_call_args, delete_call_kwargs = mock_delete.call_args
+    assert len(delete_call_args) == 1
+    assert delete_call_kwargs == {}
+
+    template_call_args, template_call_kwargs = mock_template.format.call_args
+    assert template_call_args == ()
+    assert len(template_call_kwargs) == 2
+    assert template_call_kwargs['superevent_id'] == superevent_id
+    assert template_call_kwargs['graceid'] == event_graceid
+
+
+def test_add_pipeline_preferred_event(safe_client):
+    superevent_id = 'S190302abc'
+    event_graceid = 'G123456'
+    mock_template = mock.MagicMock()
+    mock_template_dict = {'superevent-pipeline-preferred-event-list-'
+                          'template': mock_template}
+    template_prop = 'ligo.gracedb.rest.GraceDb.templates'
+    with mock.patch('ligo.gracedb.rest.GraceDb.post') as mock_post, \
+         mock.patch(template_prop, mock_template_dict):  # noqa: E127
+        safe_client.add_pipeline_preferred_event(superevent_id, event_graceid)
+
+    call_args, call_kwargs = mock_post.call_args
+    assert call_kwargs['data'] == {'event': event_graceid}
+
+    template_call_args, template_call_kwargs = mock_template.format.call_args
+    assert template_call_args == ()
+    assert len(template_call_kwargs) == 1
+    assert template_call_kwargs['superevent_id'] == superevent_id
+
+
+def test_remove_pipeline_preferred_event(safe_client):
+    superevent_id = 'S190302abc'
+    event_graceid = 'G123456'
+    mock_template = mock.MagicMock()
+    mock_template_dict = {'superevent-pipeline-preferred-'
+                          'event-detail-template': mock_template}
+    template_prop = 'ligo.gracedb.rest.GraceDb.templates'
+    with mock.patch('ligo.gracedb.rest.GraceDb.delete') as mock_delete, \
+         mock.patch(template_prop, mock_template_dict):  # noqa: E127
+        safe_client.remove_pipeline_preferred_event(superevent_id,
+                                                    event_graceid)
 
     delete_call_args, delete_call_kwargs = mock_delete.call_args
     assert len(delete_call_args) == 1
